@@ -94,7 +94,7 @@ def latitude_from_cross_section(cross):
 
 @exporter.export
 def unit_vectors_from_cross_section(cross, index='index'):
-    r"""Calculate the unit tanget and unit normal vectors from a cross-section.
+    r"""Calculate the unit tangent and unit normal vectors from a cross-section.
 
     Given a path described parametrically by :math:`\vec{l}(i) = (x(i), y(i))`, we can find
     the unit tangent vector by the formula:
@@ -292,16 +292,14 @@ def absolute_momentum(u, v, index='index'):
 
     """
     # Get the normal component of the wind
-    norm_wind = normal_component(u, v, index=index).metpy.convert_units('m/s')
+    norm_wind = normal_component(u.metpy.quantify(), v.metpy.quantify(), index=index)
 
     # Get other pieces of calculation (all as ndarrays matching shape of norm_wind)
     latitude = latitude_from_cross_section(norm_wind)
     _, latitude = xr.broadcast(norm_wind, latitude)
-    f = coriolis_parameter(np.deg2rad(latitude.values))
+    f = coriolis_parameter(latitude)
     x, y = distances_from_cross_section(norm_wind)
-    x = x.metpy.convert_units('meters')
-    y = y.metpy.convert_units('meters')
     _, x, y = xr.broadcast(norm_wind, x, y)
     distance = np.hypot(x.metpy.quantify(), y.metpy.quantify())
 
-    return norm_wind + f * distance
+    return (norm_wind + f * distance).metpy.convert_units('m/s')
