@@ -47,14 +47,20 @@ def vorticity(u, v, *, dx=None, dy=None, x_dim=-1, y_dim=-2):
     (..., M, N) `xarray.DataArray` or `pint.Quantity`
         vertical vorticity
 
-
-    .. versionchanged:: 1.0
-       Changed signature from ``(u, v, dx, dy)``
-
     See Also
     --------
     divergence
 
+    Notes
+    -----
+    This implements a numerical version of the typical vertical vorticity equation in
+    Cartesian coordinates:
+
+    .. math:: \zeta = \frac{\partial v}{\partial x} - \frac{\partial u}{\partial y}
+
+    .. versionchanged:: 1.0
+       Changed signature from ``(u, v, dx, dy)``
+
     """
     dudy = first_derivative(u, delta=dy, axis=y_dim)
     dvdx = first_derivative(v, delta=dx, axis=x_dim)
@@ -94,14 +100,21 @@ def divergence(u, v, *, dx=None, dy=None, x_dim=-1, y_dim=-2):
     (..., M, N) `xarray.DataArray` or `pint.Quantity`
         The horizontal divergence
 
-
-    .. versionchanged:: 1.0
-       Changed signature from ``(u, v, dx, dy)``
-
     See Also
     --------
     vorticity
 
+    Notes
+    -----
+    This implements a numerical version of the typical equation of 2D divergence of a vector in
+    Cartesian coordinates:
+
+    .. math:: \nabla \cdot \vec{U} =
+        \frac{\partial u}{\partial x} + \frac{\partial v}{\partial y}
+
+    .. versionchanged:: 1.0
+       Changed signature from ``(u, v, dx, dy)``
+
     """
     dudx = first_derivative(u, delta=dx, axis=x_dim)
     dvdy = first_derivative(v, delta=dy, axis=y_dim)
@@ -207,7 +220,7 @@ def stretching_deformation(u, v, dx=None, dy=None, x_dim=-1, y_dim=-2):
 @preprocess_and_wrap(wrap_like='u')
 @check_units('[speed]', '[speed]', '[length]', '[length]')
 def total_deformation(u, v, dx=None, dy=None, x_dim=-1, y_dim=-2):
-    r"""Calculate the horizontal total deformation of the horizontal wind.
+    r"""Calculate the total deformation of the horizontal wind.
 
     Parameters
     ----------
@@ -235,6 +248,10 @@ def total_deformation(u, v, dx=None, dy=None, x_dim=-1, y_dim=-2):
     (..., M, N) `xarray.DataArray` or `pint.Quantity`
         Total Deformation
 
+    See Also
+    --------
+    shearing_deformation, stretching_deformation
+
     Notes
     -----
     If inputs have more than two dimensions, they are assumed to have either leading dimensions
@@ -243,10 +260,6 @@ def total_deformation(u, v, dx=None, dy=None, x_dim=-1, y_dim=-2):
     .. versionchanged:: 1.0
        Changed signature from ``(u, v, dx, dy)``
 
-    See Also
-    --------
-    shearing_deformation, stretching_deformation
-
     """
     dudy, dudx = gradient(u, deltas=(dy, dx), axes=(y_dim, x_dim))
     dvdy, dvdx = gradient(v, deltas=(dy, dx), axes=(y_dim, x_dim))
@@ -339,7 +352,7 @@ def frontogenesis(potential_temperature, u, v, dx=None, dy=None, x_dim=-1, y_dim
     * :math:`F` is 2D kinematic frontogenesis
     * :math:`\theta` is potential temperature
     * :math:`D` is the total deformation
-    * :math:`\beta` is the angle between the axis of dilitation and the isentropes
+    * :math:`\beta` is the angle between the axis of dilatation and the isentropes
     * :math:`\delta` is the divergence
 
     Parameters
@@ -372,8 +385,8 @@ def frontogenesis(potential_temperature, u, v, dx=None, dy=None, x_dim=-1, y_dim
 
     Notes
     -----
-    Conversion factor to go from [temperature units]/m/s to [temperature units/100km/3h]
-    :math:`1.08e4*1.e5`
+    To convert from [temperature units]/m/s to [temperature units]/100km/3h, multiply by
+    :math:`1.08e9`
 
     .. versionchanged:: 1.0
        Changed signature from ``(thta, u, v, dx, dy, dim_order='yx')``
@@ -523,8 +536,7 @@ def montgomery_streamfunction(height, temperature):
     r"""Compute the Montgomery Streamfunction on isentropic surfaces.
 
     The Montgomery Streamfunction is the streamfunction of the geostrophic wind on an
-    isentropic surface. This quantity is proportional to the geostrophic wind in isentropic
-    coordinates, and its gradient can be interpreted similarly to the pressure gradient in
+    isentropic surface. Its gradient can be interpreted similarly to the pressure gradient in
     isobaric coordinates.
 
     Parameters
@@ -538,6 +550,10 @@ def montgomery_streamfunction(height, temperature):
     -------
     stream_func : `pint.Quantity` or `xarray.DataArray`
 
+    See Also
+    --------
+    get_isentropic_pressure, dry_static_energy
+
     Notes
     -----
     The formula used is that from [Lackmann2011]_ p. 69.
@@ -550,10 +566,6 @@ def montgomery_streamfunction(height, temperature):
     * :math:`C_p` is specific heat at constant pressure for dry air
     * :math:`T` is temperature of the isentropic surface
 
-    See Also
-    --------
-    get_isentropic_pressure, dry_static_energy
-
     """
     from . import dry_static_energy
     return dry_static_energy(height, temperature)
@@ -567,7 +579,7 @@ def storm_relative_helicity(height, u, v, depth, *, bottom=None, storm_u=None, s
     # Partially adapted from similar SharpPy code
     r"""Calculate storm relative helicity.
 
-    Calculates storm relatively helicity following [Markowski2010]_ pg.230-231
+    Calculates storm relative helicity following [Markowski2010]_ pg.230-231
 
     .. math:: \int\limits_0^d (\bar v - c) \cdot \bar\omega_{h} \,dz
 
@@ -767,9 +779,9 @@ def potential_vorticity_baroclinic(
     The same function can be used for isobaric and isentropic PV analysis. Provide winds
     for vorticity calculations on the desired isobaric or isentropic surface. At least three
     layers of pressure/potential temperature are required in order to calculate the vertical
-    derivative (one above and below the desired surface). The first two terms will be zero if
-    isentropic level data is used due to the gradient of theta in both the x and y-directions
-    will be zero since you are on an isentropic surface.
+    derivative (one above and below the desired surface). The first two terms will be zero
+    if isentropic level data is used. This is because the gradient of theta in both the x
+    and y-directions is zero when you are on an isentropic surface.
 
     This function expects pressure/isentropic level to increase with increasing array element
     (e.g., from higher in the atmosphere to closer to the surface. If the pressure array is
