@@ -840,11 +840,7 @@ def lat_lon_grid_deltas(longitude, latitude, x_dim=-1, y_dim=-2, geod=None):
     take_y = make_take(latitude.ndim, y_dim)
     take_x = make_take(latitude.ndim, x_dim)
 
-    if geod is None:
-        g = Geod(ellps='sphere')
-    else:
-        g = geod
-
+    g = Geod(ellps='sphere') if geod is None else geod
     forward_az, _, dy = g.inv(longitude[take_y(slice(None, -1))],
                               latitude[take_y(slice(None, -1))],
                               longitude[take_y(slice(1, None))],
@@ -891,11 +887,7 @@ def azimuth_range_to_lat_lon(azimuths, ranges, center_lon, center_lat, geod=None
     Credit to Brian Blaylock for the original implementation.
 
     """
-    if geod is None:
-        g = Geod(ellps='sphere')
-    else:
-        g = geod
-
+    g = Geod(ellps='sphere') if geod is None else geod
     try:  # convert range units to meters
         ranges = ranges.m_as('meters')
     except AttributeError:  # no units associated
@@ -1178,6 +1170,10 @@ def gradient(f, axes=None, coordinates=None, deltas=None):
     tuple of array-like
         The first derivative calculated along each specified axis of the original array
 
+    See Also
+    --------
+    laplacian, first_derivative
+
     Notes
     -----
     If this function is used without the `axes` parameter, the length of `coordinates` or
@@ -1186,10 +1182,6 @@ def gradient(f, axes=None, coordinates=None, deltas=None):
     .. versionchanged:: 1.0
        Changed signature from ``(f, **kwargs)``
 
-    See Also
-    --------
-    laplacian, first_derivative
-
     """
     pos_kwarg, positions, axes = _process_gradient_args(f, axes, coordinates, deltas)
     return tuple(first_derivative(f, axis=axis, **{pos_kwarg: positions[ind]})
@@ -1232,6 +1224,10 @@ def laplacian(f, axes=None, coordinates=None, deltas=None):
     array-like
         The laplacian
 
+    See Also
+    --------
+    gradient, second_derivative
+
     Notes
     -----
     If this function is used without the `axes` parameter, the length of `coordinates` or
@@ -1240,10 +1236,6 @@ def laplacian(f, axes=None, coordinates=None, deltas=None):
     .. versionchanged:: 1.0
        Changed signature from ``(f, **kwargs)``
 
-    See Also
-    --------
-    gradient, second_derivative
-
     """
     pos_kwarg, positions, axes = _process_gradient_args(f, axes, coordinates, deltas)
     derivs = [second_derivative(f, axis=axis, **{pos_kwarg: positions[ind]})
@@ -1454,17 +1446,12 @@ def angle_to_direction(input_angle, full=False, level=3):
     round_angles[np.where(np.isnan(round_angles))] = UND_ANGLE
 
     dir_str_arr = itemgetter(*round_angles)(angle_dict)  # for array
-    if full:
-        dir_str_arr = ','.join(dir_str_arr)
-        dir_str_arr = _unabbrieviate_direction(dir_str_arr)
-        if not scalar:
-            dir_str = dir_str_arr.split(',')
-        else:
-            dir_str = dir_str_arr.replace(',', ' ')
-    else:
-        dir_str = dir_str_arr
+    if not full:
+        return dir_str_arr
 
-    return dir_str
+    dir_str_arr = ','.join(dir_str_arr)
+    dir_str_arr = _unabbrieviate_direction(dir_str_arr)
+    return dir_str_arr.replace(',', ' ') if scalar else dir_str_arr.split(',')
 
 
 def _unabbrieviate_direction(abb_dir_str):
