@@ -24,10 +24,11 @@ try:
         def geometries(self):
             """Return an iterator of (shapely) geometries for this feature."""
             import cartopy.io.shapereader as shapereader
+
             # Ensure that the associated files are in the cache
             fname = f'{self.name}_{self.scaler.scale}'
             for extension in ['.dbf', '.shx']:
-                get_test_data(fname + extension)
+                get_test_data(fname + extension, as_file_obj=False)
             path = get_test_data(fname + '.shp', as_file_obj=False)
             return iter(tuple(shapereader.Reader(path).geometries()))
 
@@ -54,8 +55,11 @@ try:
 
     USSTATES = MetPyMapFeature('us_states', '20m', facecolor='None', edgecolor='black')
 except ImportError:
+    # If no Cartopy is present, we just don't have map features
     pass
 
+__all__ = ['USCOUNTIES', 'USSTATES']
+
 
 def import_cartopy():
     """Import CartoPy; return a stub if unable.
@@ -72,6 +76,6 @@ def import_cartopy():
 class CartopyStub:
     """Fail if a CartoPy attribute is accessed."""
 
-    def __getattr__(self, item):
+    def __getattr__(self, name):
         """Raise an error on any attribute access."""
-        raise RuntimeError(f'CartoPy is required to use this feature ({item}).')
+        raise AttributeError(f'Cannot use {name} without Cartopy installed.')
