@@ -2,6 +2,7 @@
 # Distributed under the terms of the BSD 3-Clause License.
 # SPDX-License-Identifier: BSD-3-Clause
 """Tests for the `skewt` module."""
+import warnings
 
 import matplotlib
 from matplotlib.gridspec import GridSpec
@@ -15,7 +16,7 @@ from metpy.units import units
 MPL_VERSION = matplotlib.__version__[:3]
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, style='default', tolerance=0.023)
+@pytest.mark.mpl_image_compare(remove_text=True, style='default', tolerance=0.069)
 def test_skewt_api():
     """Test the SkewT API."""
     with matplotlib.rc_context({'axes.autolimit_mode': 'data'}):
@@ -46,8 +47,7 @@ def test_skewt_api():
     return fig
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, style='default',
-                               tolerance={'3.0': 34.37}.get(MPL_VERSION, 0.02))
+@pytest.mark.mpl_image_compare(remove_text=True, style='default', tolerance=0.)
 def test_skewt_api_units():
     """#Test the SkewT API when units are provided."""
     with matplotlib.rc_context({'axes.autolimit_mode': 'data'}):
@@ -71,8 +71,7 @@ def test_skewt_api_units():
     return fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0. if matplotlib.__version__ >= '3.2' else 30.,
-                               remove_text=True, style='default')
+@pytest.mark.mpl_image_compare(tolerance=0., remove_text=True, style='default')
 def test_skewt_default_aspect_empty():
     """Test SkewT with default aspect and no plots, only special lines."""
     # With this rotation and the default aspect, this matches exactly the NWS SkewT PDF
@@ -84,8 +83,6 @@ def test_skewt_default_aspect_empty():
     return fig
 
 
-@pytest.mark.skipif(matplotlib.__version__ < '3.2',
-                    reason='Matplotlib versions generate different image sizes.')
 @pytest.mark.mpl_image_compare(tolerance=0., remove_text=False, style='default',
                                savefig_kwargs={'bbox_inches': 'tight'})
 def test_skewt_tight_bbox():
@@ -294,12 +291,12 @@ def test_hodograph_api():
     hodo = Hodograph(ax, component_range=60)
     hodo.add_grid(increment=5, color='k')
     hodo.plot([1, 10], [1, 10], color='red')
-    hodo.plot_colormapped(np.array([1, 3, 5, 10]), np.array([2, 4, 6, 11]),
+    hodo.plot_colormapped(np.array([1, 3, 5, 10]), -np.array([2, 4, 6, 11]),
                           np.array([0.1, 0.3, 0.5, 0.9]), cmap='Greys')
     return fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0, remove_text=True)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.6 if MPL_VERSION == '3.3' else 0.)
 def test_hodograph_units():
     """Test passing unit-ed quantities to Hodograph."""
     fig = plt.figure(figsize=(9, 9))
@@ -308,7 +305,7 @@ def test_hodograph_units():
     u = np.arange(10) * units.kt
     v = np.arange(10) * units.kt
     hodo.plot(u, v)
-    hodo.plot_colormapped(u, v, np.sqrt(u * u + v * v), cmap='Greys')
+    hodo.plot_colormapped(u, -v, np.hypot(u, v), cmap='Greys')
     ax.set_xlabel('')
     ax.set_ylabel('')
     return fig
@@ -326,7 +323,7 @@ def test_hodograph_masked_array():
     intervals = units.Quantity(np.array([0.0, 3.0, 6.0, 9.0, 12.0, 15.0]), 'km')
     colors = ['red', 'green', 'yellow', 'blue', 'purple']
     # Check that we're not triggering interpolation warnings
-    with pytest.warns(None) as record:
+    with warnings.catch_warnings(record=True) as record:
         hodo.plot_colormapped(u, v, h, intervals=intervals, colors=colors)
         assert len(record) == 0
     return fig
