@@ -104,6 +104,16 @@ def test_bad(func, args, kwargs, bad_parts):
         assert 'unitless_const' not in message
 
 
+@pytest.mark.parametrize('func', test_funcs, ids=['some kwargs', 'all kwargs', 'all pos'])
+def test_bad_masked_array(func):
+    """Test getting a masked array-specific message when missing units."""
+    with pytest.raises(ValueError) as exc:
+        func(np.ma.array([30]), 1000 * units.mbar, 1.0 * units('kg/m^3'), 1, 5.)
+
+    message = str(exc.value)
+    assert 'units.Quantity' in message
+
+
 def test_pandas_units_simple():
     """Simple unit attachment to two columns."""
     df = pd.DataFrame(data=[[1, 4], [2, 5], [3, 6]], columns=['cola', 'colb'])
@@ -190,6 +200,24 @@ def test_percent_units():
     assert str(units('%').units) == 'percent'
 
 
-def test_udunits_power_syntax():
+@pytest.mark.parametrize(
+    'unit_str,pint_unit',
+    (
+        # Validated against cf-units (UDUNITS-2 wrapper)
+        ('m s-1', units.m / units.s),
+        ('m2 s-2', units.m ** 2 / units.s ** 2),
+        ('kg(-1)', units.kg),
+        ('kg-1', units.kg ** -1),
+        ('W m(-2)', units.m ** 3 * units.kg * units.s ** -3),
+        ('W m-2', units.kg * units.s ** -3),
+        ('(W m-2 um-1)-1', units.m * units.kg ** -1 * units.s ** 3),
+        pytest.param(
+            '(J kg-1)(m s-1)-1', units.m / units.s,
+            marks=pytest.mark.xfail(reason='hgrecco/pint#1485')
+        ),
+        ('(J kg-1)(m s-1)(-1)', units.m ** 3 / units.s ** 3)
+    )
+)
+def test_udunits_power_syntax(unit_str, pint_unit):
     """Test that UDUNITS style powers are properly parsed and interpreted."""
-    assert units('m2 s-2').units == units.m ** 2 / units.s ** 2
+    assert units(unit_str).to_base_units().units == pint_unit
